@@ -9,11 +9,13 @@ from _pytest.config import Config
 from _pytest.nodes import Item
 from freezegun import freeze_time
 from pytest import fixture
-from pytest_mock.plugin import MockerFixture
 from typeguard import typechecked
 from typeguard.importhook import install_import_hook
 
 
+pytest_plugins = ["logutils.pytest_plugin"]
+
+
 def pytest_configure(config: Config) -> None:
     """Initial pytest configuration hook.
 
@@ -50,24 +52,6 @@ def pytest_runtest_call(item: Item) -> None:
         setattr(item, "obj", typechecked(test_func))
 
 
-@fixture
-def mock_dynamic_log_fields(mocker: MockerFixture) -> None:
-    """Mock dynamic fields that may be contained in log records."""
-    mocker.patch("logutils.api.getpid", return_value=12345)
-
-    frameinfo = mocker.MagicMock()
-    setattr(frameinfo, "function", "fake_function")
-    setattr(frameinfo, "lineno", "123")
-    mocker.patch(
-        "logutils.api.getframeinfo",
-        return_value=frameinfo,
-    )
-
-    mod = mocker.MagicMock()
-    setattr(mod, "__name__", "fake_module")
-    mocker.patch("logutils.api.getmodule", return_value=mod)
-
-
 @fixture(autouse=True, scope="session")
 def frozen_time() -> Iterator[None]:
     """Freeze time until our tests are done running."""
